import type { Image, PineOptions, InjectedDependenciesParam } from '..';
declare const getImageModel: (deps: InjectedDependenciesParam) => {
    /**
     * @summary Get a specific image
     * @name get
     * @public
     * @function
     * @memberof balena.models.image
     *
     * @param {Number} id - image id
     * @param {Object} [options={}] - extra pine options to use
     * @fulfil {Object} - image
     * @returns {Promise}
     *
     * @example
     * balena.models.image.get(123).then(function(image) {
     * 	console.log(image);
     * });
     */
    get(id: number, options?: PineOptions<Image>): Promise<Image>;
    /**
     * @summary Get the logs for an image
     * @name getLogs
     * @public
     * @function
     * @memberof balena.models.image
     *
     * @param {Number} id - image id
     * @fulfil {string} - logs
     * @returns {Promise}
     *
     * @example
     * balena.models.image.getLogs(123).then(function(logs) {
     * 	console.log(logs);
     * });
     */
    getLogs: (id: number) => Promise<string>;
};
export default getImageModel;
