import type { Pine } from './pine';
import type { BalenaRequest, Interceptor } from 'balena-request';
export type { Pine, PineStrict } from './pine';
export * from './types/models';
export * from './types/jwt';
export * from './types/contract';
export * from './types/user-invite';
export * from './types/auth';
export type { Interceptor };
export type { WithId, PineDeferred, NavigationResource, OptionalNavigationResource, ReverseNavigationResource, ParamsObj as PineParams, ParamsObjWithId as PineParamsWithId, Filter as PineFilter, Expand as PineExpand, ODataOptions as PineOptions, SubmitBody as PineSubmitBody, ODataOptionsWithFilter as PineOptionsWithFilter, ODataOptionsStrict as PineOptionsStrict, SelectableProps as PineSelectableProps, ExpandableProps as PineExpandableProps, ExpandResultObject as PineExpandResultObject, TypedResult as PineTypedResult, PostResult as PinePostResult, } from '../typings/pinejs-client-core';
export type { ApplicationMembershipCreationOptions } from './models/application-membership';
export type { ApplicationInviteOptions } from './models/application-invite';
export type { BankAccountBillingInfo, BillingAccountAddressInfo, BillingAccountInfo, BillingAddonPlanInfo, BillingInfo, BillingInfoType, BillingPlanBillingInfo, BillingPlanInfo, CardBillingInfo, InvoiceInfo, PlanChangeOptions, TokenBillingSubmitInfo, } from './models/billing';
export type { GaConfig, Config, ConfigVarDefinition, DeviceTypeJson, } from './models/config';
export type { DeviceState, DeviceMetrics, OverallStatus, SupervisorStatus, } from './models/device';
export type { ReleaseWithImageDetails } from './models/release';
export type { OrganizationMembershipCreationOptions } from './models/organization-membership';
export type { OrganizationInviteOptions } from './models/organization-invite';
export type { ImgConfigOptions, OsDownloadOptions, OsLines, OsTypes, OsUpdateVersions, OsVersion, OsVersionsByDeviceType, } from './models/os';
export type { OsUpdateActionResult } from './util/device-actions/os-update';
export type { BuilderUrlDeployOptions } from './util/builder';
export type { CurrentService, CurrentServiceWithCommit, DeviceWithServiceDetails, } from './util/device-service-details';
export type { BaseLog, ServiceLog, SystemLog, LogMessage, LogsSubscription, LogsOptions, } from './logs';
export interface InjectedDependenciesParam {
    sdkInstance: BalenaSDK;
    settings: {
        get(key: string): string;
        getAll(): {
            [key: string]: string;
        };
    };
    request: BalenaRequest;
    auth: import('balena-auth').default;
    pine: Pine;
    pubsub: import('./util/pubsub').PubSub;
}
export interface SdkOptions {
    apiUrl?: string;
    builderUrl?: string;
    dashboardUrl?: string;
    dataDirectory?: string | false;
    isBrowser?: boolean;
    debug?: boolean;
    deviceUrlsBase?: string;
    requestLimit?: number;
    requestLimitInterval?: number;
    retryRateLimitedRequests?: boolean;
    requestBatchingChunkSize?: number | {
        numericId: number;
        stringId: number;
    };
}
export interface InjectedOptionsParam extends SdkOptions {
    apiUrl: string;
    apiVersion: string;
}
declare const sdkTemplate: {
    auth(): (deps: InjectedDependenciesParam, opts: InjectedOptionsParam) => {
        twoFactor: {
            isEnabled: () => Promise<boolean>;
            isPassed: () => Promise<boolean>;
            getSetupKey: () => Promise<string>;
            enable: (code: string) => Promise<string>;
            verify: (code: string) => Promise<string>;
            challenge: (code: string) => Promise<void>;
            disable: (password: string) => Promise<string>;
        };
        whoami: () => Promise<import("./types/auth").WhoamiResult | undefined>;
        authenticate: (credentials: {
            email: string;
            password: string;
        }) => Promise<string>;
        login: (credentials: {
            email: string;
            password: string;
        }) => Promise<void>;
        loginWithToken: (authToken: string) => Promise<void>;
        isLoggedIn: () => Promise<boolean>;
        getToken: () => Promise<string>;
        getActorId: () => Promise<number>;
        getUserInfo: () => Promise<import("./types/auth").UserInfo>;
        logout: () => Promise<void>;
        register: (credentials: {
            email: string;
            password: string;
            'g-recaptcha-response'?: string | undefined;
        }) => Promise<string>;
        verifyEmail: (verificationPayload: {
            email: string;
            token: string;
        }) => Promise<string>;
        requestVerificationEmail: () => Promise<void>;
    };
    models(): (deps: InjectedDependenciesParam, opts: InjectedOptionsParam) => {
        application: {
            _getId: (slugOrUuidOrId: string | number) => Promise<number>;
            getDashboardUrl(id: number): string;
            getAll(options?: import("../typings/pinejs-client-core").ODataOptions<import("./types/models").Application> | undefined, context?: "directly_accessible" | undefined): Promise<import("./types/models").Application[]>;
            getAllDirectlyAccessible(options?: import("../typings/pinejs-client-core").ODataOptions<import("./types/models").Application> | undefined): Promise<import("./types/models").Application[]>;
            get(slugOrUuidOrId: string | number, options?: import("../typings/pinejs-client-core").ODataOptions<import("./types/models").Application> | undefined, context?: "directly_accessible" | undefined): Promise<import("./types/models").Application>;
            getDirectlyAccessible(slugOrUuidOrId: string | number, options?: import("../typings/pinejs-client-core").ODataOptions<import("./types/models").Application> | undefined): Promise<import("./types/models").Application>;
            getWithDeviceServiceDetails(slugOrUuidOrId: string | number, options?: import("../typings/pinejs-client-core").ODataOptions<import("./types/models").Application> | undefined): Promise<import("./types/models").Application & {
                owns__device: import("./util/device-service-details").DeviceWithServiceDetails<import("./util/device-service-details").CurrentServiceWithCommit>[];
            }>;
            getAppByName(appName: string, options?: import("../typings/pinejs-client-core").ODataOptions<import("./types/models").Application> | undefined, context?: "directly_accessible" | undefined): Promise<import("./types/models").Application>;
            getAppByOwner(appName: string, owner: string, options?: import("../typings/pinejs-client-core").ODataOptions<import("./types/models").Application> | undefined): Promise<import("./types/models").Application>;
            has: (slugOrUuidOrId: string | number) => Promise<boolean>;
            hasAny: () => Promise<boolean>;
            create({ name, applicationType, applicationClass, deviceType, parent, organization, }: {
                name: string;
                applicationType?: string | undefined;
                applicationClass?: "block" | "fleet" | "app" | undefined;
                deviceType: string;
                parent?: string | number | undefined;
                organization: string | number;
            }): Promise<import("../typings/pinejs-client-core").PostResult<import("./types/models").Application>>;
            remove: (slugOrUuidOrIdOrIds: string | number | number[]) => Promise<void>;
            rename: (slugOrUuidOrId: string | number, newAppName: string) => Promise<void>;
            restart: (slugOrUuidOrId: string | number) => Promise<void>;
            generateApiKey: (slugOrUuidOrId: string | number) => Promise<string>;
            generateProvisioningKey: (slugOrUuidOrId: string | number, keyName?: string | undefined, keyDescription?: string | undefined, keyExpiryDate?: string | undefined) => Promise<string>;
            purge: (appId: number) => Promise<void>;
            shutdown: (appId: number, options?: {
                force?: boolean | undefined;
            } | undefined) => Promise<void>;
            reboot: (appId: number, options?: {
                force?: boolean | undefined;
            } | undefined) => Promise<void>;
            willTrackNewReleases: (slugOrUuidOrId: string | number) => Promise<boolean>;
            isTrackingLatestRelease: (slugOrUuidOrId: string | number) => Promise<boolean>;
            pinToRelease: (slugOrUuidOrId: string | number, fullReleaseHash: string) => Promise<void>;
            getTargetReleaseHash: (slugOrUuidOrId: string | number) => Promise<string | undefined>;
            trackLatestRelease: (slugOrUuidOrId: string | number) => Promise<void>;
            enableDeviceUrls: (slugOrUuidOrId: string | number) => Promise<void>;
            disableDeviceUrls: (slugOrUuidOrId: string | number) => Promise<void>;
            grantSupportAccess(slugOrUuidOrId: string | number, expiryTimestamp: number): Promise<void>;
            revokeSupportAccess: (slugOrUuidOrId: string | number) => Promise<void>;
            tags: {
                getAllByApplication: (parentParam: string | number | import("../typings/utils").Dictionary<unknown>, options?: import("../typings/pinejs-client-core").ODataOptions<import("./types/models").ApplicationTag> | undefined) => Promise<import("./types/models").ApplicationTag[]>;
                set: (parentParam: string | number | import("../typings/utils").Dictionary<unknown>, key: string, value: string) => Promise<void>;
                remove: (parentParam: string | number | import("../typings/utils").Dictionary<unknown>, key: string) => Promise<void>;
            };
            configVar: {
                getAllByApplication: (parentParam: string | number | import("../typings/utils").Dictionary<unknown>, options?: import("../typings/pinejs-client-core").ODataOptions<import("./types/models").ApplicationVariable> | undefined) => Promise<import("./types/models").ApplicationVariable[]>;
                get: (parentParam: string | number | import("../typings/utils").Dictionary<unknown>, key: string) => Promise<string | undefined>;
                set: (parentParam: string | number | import("../typings/utils").Dictionary<unknown>, key: string, value: string) => Promise<void>;
                remove: (parentParam: string | number | import("../typings/utils").Dictionary<unknown>, key: string) => Promise<void>;
            };
            envVar: {
                getAllByApplication: (parentParam: string | number | import("../typings/utils").Dictionary<unknown>, options?: import("../typings/pinejs-client-core").ODataOptions<import("./types/models").ApplicationVariable> | undefined) => Promise<import("./types/models").ApplicationVariable[]>;
                get: (parentParam: string | number | import("../typings/utils").Dictionary<unknown>, key: string) => Promise<string | undefined>;
                set: (parentParam: string | number | import("../typings/utils").Dictionary<unknown>, key: string, value: string) => Promise<void>;
                remove: (parentParam: string | number | import("../typings/utils").Dictionary<unknown>, key: string) => Promise<void>;
            };
            buildVar: {
                getAllByApplication: (parentParam: string | number | import("../typings/utils").Dictionary<unknown>, options?: import("../typings/pinejs-client-core").ODataOptions<import("./types/models").BuildVariable> | undefined) => Promise<import("./types/models").BuildVariable[]>;
                get: (parentParam: string | number | import("../typings/utils").Dictionary<unknown>, key: string) => Promise<string | undefined>;
                set: (parentParam: string | number | import("../typings/utils").Dictionary<unknown>, key: string, value: string) => Promise<void>;
                remove: (parentParam: string | number | import("../typings/utils").Dictionary<unknown>, key: string) => Promise<void>;
            };
            membership: {
                get(membershipId: number | import("../typings/pinejs-client-core").SubmitBody<Pick<import("./types/models").ApplicationMembership, "user" | "is_member_of__application">>, options?: import("../typings/pinejs-client-core").ODataOptions<import("./types/models").ApplicationMembership>): Promise<import("./types/models").ApplicationMembership>;
                getAllByApplication(slugOrUuidOrId: string | number, options?: import("../typings/pinejs-client-core").ODataOptions<import("./types/models").ApplicationMembership>): Promise<import("./types/models").ApplicationMembership[]>;
                getAllByUser(usernameOrId: string | number, options?: import("../typings/pinejs-client-core").ODataOptions<import("./types/models").ApplicationMembership>): Promise<import("./types/models").ApplicationMembership[]>;
                create({ application, username, roleName, }: import("./models/application-membership").ApplicationMembershipCreationOptions): Promise<import("../typings/pinejs-client-core").PostResult<import("./types/models").ApplicationMembership>>;
                changeRole(idOrUniqueKey: number | import("../typings/pinejs-client-core").SubmitBody<Pick<import("./types/models").ApplicationMembership, "user" | "is_member_of__application">>, roleName: string): Promise<void>;
                remove(idOrUniqueKey: number | import("../typings/pinejs-client-core").SubmitBody<Pick<import("./types/models").ApplicationMembership, "user" | "is_member_of__application">>): Promise<void>;
            };
            invite: {
                getAll(options?: import("../typings/pinejs-client-core").ODataOptions<import("./types/models").ApplicationInvite>): Promise<import("./types/models").ApplicationInvite[]>;
                getAllByApplication(slugOrUuidOrId: string | number, options?: import("../typings/pinejs-client-core").ODataOptions<import("./types/models").ApplicationInvite>): Promise<import("./types/models").ApplicationInvite[]>;
                create(slugOrUuidOrId: string | number, { invitee, roleName, message }: import("./models/application-invite").ApplicationInviteOptions): Promise<import("../typings/pinejs-client-core").PostResult<import("./types/models").ApplicationInvite>>;
                revoke(id: number): Promise<void>;
                accept(invitationToken: string): Promise<void>;
            };
        };
        device: {
            getSupervisorTargetState: (uuidOrId: string | number, version?: 2 | 3) => Promise<import("./types/device-state").DeviceState>;
            getSupervisorTargetStateForApp: (slugOrUuidOrId: string | number, release?: string | number | undefined) => Promise<import("./types/device-state").DeviceStateV3>;
            generateUniqueKey(): string;
            register(applicationSlugOrUuidOrId: string | number, uuid: string, deviceTypeSlug?: string | undefined): Promise<{
                id: number;
                uuid: string;
                api_key: string;
            }>;
            generateDeviceKey: (uuidOrId: string | number, keyName?: string | undefined, keyDescription?: string | undefined, keyExpiryDate?: string | undefined) => Promise<string>;
            hasDeviceUrl: (uuidOrId: string | number) => Promise<boolean>;
            getDeviceUrl: (uuidOrId: string | number) => Promise<string>;
            enableDeviceUrl: (uuidOrIdOrArray: string | number | string[] | number[]) => Promise<void>;
            disableDeviceUrl: (uuidOrIdOrArray: string | number | string[] | number[]) => Promise<void>;
            enableLocalMode(uuidOrId: string | number): Promise<void>;
            disableLocalMode: (uuidOrId: string | number) => Promise<void>;
            isInLocalMode: (uuidOrId: string | number) => Promise<boolean>;
            getLocalModeSupport: (device: import("../typings/utils").AtLeast<import("./types/models").Device, "last_connectivity_event" | "os_variant" | "os_version" | "supervisor_version">) => {
                supported: boolean;
                message: string;
            };
            enableLockOverride: (uuidOrId: string | number) => Promise<void>;
            disableLockOverride: (uuidOrId: string | number) => Promise<void>;
            hasLockOverride: (uuidOrId: string | number) => Promise<boolean>;
            getStatus(uuidOrId: string | number): Promise<string>;
            getProgress(uuidOrId: string | number): Promise<number | null>;
            grantSupportAccess(uuidOrIdOrArray: string | number | string[] | number[], expiryTimestamp: number): Promise<void>;
            revokeSupportAccess: (uuidOrIdOrArray: string | number | string[] | number[]) => Promise<void>;
            lastOnline(device: import("../typings/utils").AtLeast<import("./types/models").Device, "is_online" | "last_connectivity_event">): string;
            getOsVersion: (device: import("../typings/utils").AtLeast<import("./types/models").Device, "os_variant" | "os_version">) => string;
            isTrackingApplicationRelease: (uuidOrId: string | number) => Promise<boolean>;
            getTargetReleaseHash: (uuidOrId: string | number) => Promise<string | undefined>;
            pinToRelease: (uuidOrIdOrArray: string | number | string[] | number[], fullReleaseHashOrId: string | number) => Promise<void>;
            trackApplicationRelease: (uuidOrIdOrArray: string | number | string[] | number[]) => Promise<void>;
            setSupervisorRelease: (uuidOrIdOrArray: string | number | string[] | number[], supervisorVersionOrId: string | number) => Promise<void>;
            _checkOsUpdateTarget({ uuid, is_of__device_type, is_online, os_version, os_variant, }: Pick<import("./types/models").Device, "uuid" | "is_online" | "os_variant" | "os_version"> & {
                is_of__device_type: [Pick<import("./types/models").DeviceType, "slug">];
            }, targetOsVersion: string): void;
            startOsUpdate: {
                (uuidOrUuids: string, targetOsVersion: string): Promise<import("./util/device-actions/os-update").OsUpdateActionResult>;
                (uuidOrUuids: string[], targetOsVersion: string): Promise<import("../typings/utils").Dictionary<import("./util/device-actions/os-update").OsUpdateActionResult>>;
            };
            getOsUpdateStatus: (uuid: string) => Promise<import("./util/device-actions/os-update").OsUpdateActionResult>;
            tags: {
                getAllByApplication(slugOrUuidOrId: string | number, options?: import("../typings/pinejs-client-core").ODataOptions<import("./types/models").DeviceTag> | undefined): Promise<import("./types/models").DeviceTag[]>;
                getAllByDevice: (parentParam: string | number | import("../typings/utils").Dictionary<unknown>, options?: import("../typings/pinejs-client-core").ODataOptions<import("./types/models").DeviceTag> | undefined) => Promise<import("./types/models").DeviceTag[]>;
                set: (parentParam: string | number | import("../typings/utils").Dictionary<unknown>, key: string, value: string) => Promise<void>;
                remove: (parentParam: string | number | import("../typings/utils").Dictionary<unknown>, key: string) => Promise<void>;
            };
            configVar: {
                getAllByDevice: (parentParam: string | number | import("../typings/utils").Dictionary<unknown>, options?: import("../typings/pinejs-client-core").ODataOptions<import("./types/models").DeviceVariable> | undefined) => Promise<import("./types/models").DeviceVariable[]>;
                getAllByApplication(slugOrUuidOrId: string | number, options?: import("../typings/pinejs-client-core").ODataOptions<import("./types/models").DeviceVariable> | undefined): Promise<import("./types/models").DeviceVariable[]>;
                get: (parentParam: string | number | import("../typings/utils").Dictionary<unknown>, key: string) => Promise<string | undefined>;
                set: (parentParam: string | number | import("../typings/utils").Dictionary<unknown>, key: string, value: string) => Promise<void>;
                remove: (parentParam: string | number | import("../typings/utils").Dictionary<unknown>, key: string) => Promise<void>;
            };
            envVar: {
                getAllByDevice: (parentParam: string | number | import("../typings/utils").Dictionary<unknown>, options?: import("../typings/pinejs-client-core").ODataOptions<import("./types/models").DeviceVariable> | undefined) => Promise<import("./types/models").DeviceVariable[]>;
                getAllByApplication(slugOrUuidOrId: string | number, options?: import("../typings/pinejs-client-core").ODataOptions<import("./types/models").DeviceVariable> | undefined): Promise<import("./types/models").DeviceVariable[]>;
                get: (parentParam: string | number | import("../typings/utils").Dictionary<unknown>, key: string) => Promise<string | undefined>;
                set: (parentParam: string | number | import("../typings/utils").Dictionary<unknown>, key: string, value: string) => Promise<void>;
                remove: (parentParam: string | number | import("../typings/utils").Dictionary<unknown>, key: string) => Promise<void>;
            };
            serviceVar: {
                getAllByDevice(uuidOrId: string | number, options?: import("../typings/pinejs-client-core").ODataOptions<import("./types/models").DeviceServiceEnvironmentVariable> | undefined): Promise<import("./types/models").DeviceServiceEnvironmentVariable[]>;
                getAllByApplication(slugOrUuidOrId: string | number, options?: import("../typings/pinejs-client-core").ODataOptions<import("./types/models").DeviceServiceEnvironmentVariable> | undefined): Promise<import("./types/models").DeviceServiceEnvironmentVariable[]>;
                get(uuidOrId: string | number, serviceNameOrId: string | number, key: string): Promise<string | undefined>;
                set(uuidOrId: string | number, serviceNameOrId: string | number, key: string, value: string): Promise<void>;
                remove(uuidOrId: string | number, serviceNameOrId: string | number, key: string): Promise<void>;
            };
            history: {
                getAllByDevice(uuidOrId: string | number, { fromDate, toDate, ...options }?: import("../typings/pinejs-client-core").ODataOptions<import("./types/models").DeviceHistory> & {
                    fromDate?: Date | undefined;
                    toDate?: Date | undefined;
                }): Promise<import("./types/models").DeviceHistory[]>;
                getAllByApplication(slugOrUuidOrId: string | number, { fromDate, toDate, ...options }?: import("../typings/pinejs-client-core").ODataOptions<import("./types/models").DeviceHistory> & {
                    fromDate?: Date | undefined;
                    toDate?: Date | undefined;
                }): Promise<import("./types/models").DeviceHistory[]>;
            };
            ping: (uuidOrId: string | number) => Promise<void>;
            getApplicationInfo: (uuidOrId: string | number) => Promise<{
                appId: string;
                commit: string;
                containerId: string;
                env: {
                    [key: string]: string | number;
                };
                imageId: string;
            }>;
            identify: (uuidOrId: string | number) => Promise<void>;
            restartApplication: (uuidOrId: string | number) => Promise<void>;
            startApplication: (uuidOrId: string | number) => Promise<void>;
            stopApplication: (uuidOrId: string | number) => Promise<void>;
            reboot: (uuidOrId: string | number, options?: {
                force?: boolean | undefined;
            } | undefined) => Promise<void>;
            shutdown: (uuidOrId: string | number, options: {
                force?: boolean | undefined;
            }) => Promise<void>;
            purge: (uuidOrId: string | number) => Promise<void>;
            update(uuidOrId: string | number, options: {
                force?: boolean | undefined;
            }): Promise<void>;
            getSupervisorState: (uuidOrId: string | number) => Promise<import("./models/device.supervisor-api.partial").SupervisorStatus>;
            startService: (uuidOrId: string | number, imageId: number) => Promise<void>;
            stopService: (uuidOrId: string | number, imageId: number) => Promise<void>;
            restartService: (uuidOrId: string | number, imageId: number) => Promise<void>;
            _getId: (uuidOrId: string | number) => Promise<number>;
            OverallStatus: typeof import("./types/device-overall-status").DeviceOverallStatus;
            getDashboardUrl(uuid: string): string;
            getAllByApplication(slugOrUuidOrId: string | number, options?: import("../typings/pinejs-client-core").ODataOptions<import("./types/models").Device> | undefined): Promise<import("./types/models").Device[]>;
            getAllByOrganization(handleOrId: string | number, options?: import("../typings/pinejs-client-core").ODataOptions<import("./types/models").Device> | undefined): Promise<import("./types/models").Device[]>;
            get(uuidOrId: string | number, options?: import("../typings/pinejs-client-core").ODataOptions<import("./types/models").Device> | undefined): Promise<import("./types/models").Device>;
            getWithServiceDetails(uuidOrId: string | number, options?: import("../typings/pinejs-client-core").ODataOptions<import("./types/models").Device> | undefined): Promise<import("./util/device-service-details").DeviceWithServiceDetails<import("./util/device-service-details").CurrentServiceWithCommit>>;
            getByName(name: string, options?: import("../typings/pinejs-client-core").ODataOptions<import("./types/models").Device> | undefined): Promise<import("./types/models").Device[]>;
            getName: (uuidOrId: string | number) => Promise<string>;
            getApplicationName: (uuidOrId: string | number) => Promise<string>;
            has: (uuidOrId: string | number) => Promise<boolean>;
            isOnline: (uuidOrId: string | number) => Promise<boolean>;
            getLocalIPAddresses: (uuidOrId: string | number) => Promise<string[]>;
            getMACAddresses: (uuidOrId: string | number) => Promise<string[]>;
            getMetrics: (uuidOrId: string | number) => Promise<import("./models/device").DeviceMetrics>;
            remove: (uuidOrIdOrArray: string | number | string[] | number[]) => Promise<void>;
            deactivate: (uuidOrIdOrArray: string | number | string[] | number[]) => Promise<void>;
            rename: (uuidOrId: string | number, newName: string) => Promise<void>;
            setNote: (uuidOrIdOrArray: string | number | string[] | number[], note: string) => Promise<void>;
            setCustomLocation: (uuidOrIdOrArray: string | number | string[] | number[], location: {
                latitude: string | number;
                longitude: string | number;
            }) => Promise<void>;
            unsetCustomLocation: (uuidOrIdOrArray: string | number | string[] | number[]) => Promise<void>;
            move: (uuidOrIdOrArray: string | number | string[] | number[], applicationSlugOrUuidOrId: string | number) => Promise<void>;
        };
        deviceType: {
            get(idOrSlug: string | number, options?: import("../typings/pinejs-client-core").ODataOptions<import("./types/models").DeviceType> | undefined): Promise<import("./types/models").DeviceType>;
            getAll(options?: import("../typings/pinejs-client-core").ODataOptions<import("./types/models").DeviceType> | undefined): Promise<import("./types/models").DeviceType[]>;
            getAllSupported(options?: import("../typings/pinejs-client-core").ODataOptions<import("./types/models").DeviceType> | undefined): Promise<import("./types/models").DeviceType[]>;
            getBySlugOrName: (slugOrName: string, options?: import("../typings/pinejs-client-core").ODataOptions<import("./types/models").DeviceType> | undefined) => Promise<import("./types/models").DeviceType>;
            getName: (deviceTypeSlug: string) => Promise<string>;
            getSlugByName: (deviceTypeName: string) => Promise<string>;
            getInterpolatedPartials: (deviceTypeSlug: string) => Promise<import("./types/contract").Contract>;
            getInstructions: (deviceTypeSlugOrContract: string | import("./types/contract").Contract) => Promise<string[] | Record<"Linux" | "MacOS" | "Windows", string[]>>;
            getInstallMethod: (deviceTypeSlug: string) => Promise<string | null>;
        };
        apiKey: {
            create(name: string, description?: string | null, expiryDate?: string | null): Promise<string>;
            getAll(options?: import("../typings/pinejs-client-core").ODataOptions<import("./types/models").ApiKey>): Promise<import("./types/models").ApiKey[]>;
            getAllNamedUserApiKeys(options?: import("../typings/pinejs-client-core").ODataOptions<import("./types/models").ApiKey>): Promise<import("./types/models").ApiKey[]>;
            getProvisioningApiKeysByApplication(slugOrUuidOrId: string | number, options?: import("../typings/pinejs-client-core").ODataOptions<import("./types/models").ApiKey>): Promise<import("./types/models").ApiKey[]>;
            getDeviceApiKeysByDevice(uuidOrId: string | number, options?: import("../typings/pinejs-client-core").ODataOptions<import("./types/models").ApiKey>): Promise<import("./types/models").ApiKey[]>;
            update(id: number, apiKeyInfo: {
                name?: string | undefined;
                description?: string | null | undefined;
                expiryDate?: string | null | undefined;
            }): Promise<void>;
            revoke(id: number): Promise<void>;
        };
        key: {
            getAll: (options?: import("../typings/pinejs-client-core").ODataOptions<import("./types/models").SSHKey>) => Promise<import("./types/models").SSHKey[]>;
            get: (id: number) => Promise<import("./types/models").SSHKey>;
            remove: (id: number) => Promise<string>;
            create: (title: string, key: string) => Promise<import("../typings/pinejs-client-core").PostResult<import("./types/models").SSHKey>>;
        };
        organization: {
            create: (organization: import("../typings/pinejs-client-core").SubmitBody<import("./types/models").Organization>) => Promise<import("../typings/pinejs-client-core").PostResult<import("./types/models").Organization>>;
            getAll: (options?: import("../typings/pinejs-client-core").ODataOptions<import("./types/models").Organization>) => Promise<import("./types/models").Organization[]>;
            get: (handleOrId: string | number, options?: import("../typings/pinejs-client-core").ODataOptions<import("./types/models").Organization>) => Promise<import("./types/models").Organization>;
            remove: (handleOrId: string | number) => Promise<void>;
            membership: {
                get(membershipId: number | import("../typings/pinejs-client-core").SubmitBody<Pick<import("./types/models").OrganizationMembership, "user" | "is_member_of__organization">>, options?: import("../typings/pinejs-client-core").ODataOptions<import("./types/models").OrganizationMembership>): Promise<import("./types/models").OrganizationMembership>;
                getAllByOrganization(handleOrId: string | number, options?: import("../typings/pinejs-client-core").ODataOptions<import("./types/models").OrganizationMembership>): Promise<import("./types/models").OrganizationMembership[]>;
                getAllByUser(usernameOrId: string | number, options?: import("../typings/pinejs-client-core").ODataOptions<import("./types/models").OrganizationMembership>): Promise<import("./types/models").OrganizationMembership[]>;
                create({ organization, username, roleName, }: import("./models/organization-membership").OrganizationMembershipCreationOptions): Promise<import("../typings/pinejs-client-core").PostResult<import("./types/models").OrganizationMembership>>;
                changeRole(idOrUniqueKey: number | import("../typings/pinejs-client-core").SubmitBody<Pick<import("./types/models").OrganizationMembership, "user" | "is_member_of__organization">>, roleName: string): Promise<void>;
                remove(idOrUniqueKey: number | import("../typings/pinejs-client-core").SubmitBody<Pick<import("./types/models").OrganizationMembership, "user" | "is_member_of__organization">>): Promise<void>;
                tags: {
                    getAllByOrganization(handleOrId: string | number, options?: import("../typings/pinejs-client-core").ODataOptions<import("./types/models").OrganizationMembershipTag> | undefined): Promise<import("./types/models").OrganizationMembershipTag[]>;
                    getAllByOrganizationMembership: (parentParam: string | number | import("../typings/utils").Dictionary<unknown>, options?: import("../typings/pinejs-client-core").ODataOptions<import("./types/models").OrganizationMembershipTag> | undefined) => Promise<import("./types/models").OrganizationMembershipTag[]>;
                    set: (parentParam: string | number | import("../typings/utils").Dictionary<unknown>, key: string, value: string) => Promise<void>;
                    remove: (parentParam: string | number | import("../typings/utils").Dictionary<unknown>, key: string) => Promise<void>;
                };
            };
            invite: {
                getAll(options?: import("../typings/pinejs-client-core").ODataOptions<import("./types/models").OrganizationInvite>): Promise<import("./types/models").OrganizationInvite[]>;
                getAllByOrganization(handleOrId: string | number, options?: import("../typings/pinejs-client-core").ODataOptions<import("./types/models").OrganizationInvite>): Promise<import("./types/models").OrganizationInvite[]>;
                create(handleOrId: string | number, { invitee, roleName, message }: import("./models/organization-invite").OrganizationInviteOptions): Promise<import("../typings/pinejs-client-core").PostResult<import("./types/models").OrganizationInvite>>;
                revoke(id: number): Promise<void>;
                accept(invitationToken: string): Promise<void>;
            };
        };
        os: {
            _getNormalizedDeviceTypeSlug: (deviceTypeSlug: string) => Promise<string>;
            _getDownloadSize: (deviceType: string, version: string) => Promise<number>;
            _clearDeviceTypesAndOsVersionCaches: () => void;
            _getMaxSatisfyingVersion: (versionOrRange: string, osVersions: Pick<import("./models/os").OsVersion, "raw_version" | "isRecommended">[]) => string | null | undefined;
            OsTypes: typeof import("./models/os").OsTypes;
            getAllOsVersions: {
                <TP extends import("../typings/pinejs-client-core").ODataOptions<import("./types/models").Release> | undefined>(deviceType: string, options?: TP | undefined): Promise<import("./util").ExtendedPineTypedResult<import("./types/models").Release, import("./models/os").OsVersion, TP>[]>;
                <TP_1 extends import("../typings/pinejs-client-core").ODataOptions<import("./types/models").Release> | undefined>(deviceTypes: string[], options?: TP_1 | undefined): Promise<import("../typings/utils").Dictionary<import("./util").ExtendedPineTypedResult<import("./types/models").Release, import("./models/os").OsVersion, TP_1>[]>>;
            };
            getAvailableOsVersions: {
                (deviceType: string, options?: {
                    includeDraft?: boolean | undefined;
                } | undefined): Promise<import("./models/os").OsVersion[]>;
                (deviceTypes: string[], options?: {
                    includeDraft?: boolean | undefined;
                } | undefined): Promise<import("../typings/utils").Dictionary<import("./models/os").OsVersion[]>>;
            };
            getMaxSatisfyingVersion: (deviceType: string, versionOrRange?: string, osType?: "default" | "esr" | undefined) => Promise<string | null>;
            getDownloadSize: (deviceType: string, version?: string) => Promise<number>;
            getLastModified: (deviceType: string, version?: string) => Promise<Date>;
            download: (() => never) | (({ deviceType, version, ...restOptions }: import("./models/os").OsDownloadOptions) => Promise<import("balena-request").BalenaRequestStreamResult>);
            getConfig: (slugOrUuidOrId: string | number, options: import("./models/os").ImgConfigOptions) => Promise<object>;
            isSupportedOsUpdate: (deviceType: string, currentVersion: string, targetVersion: string) => Promise<boolean>;
            getSupportedOsUpdateVersions: (deviceType: string, currentVersion: string, options?: {
                includeDraft?: boolean | undefined;
            } | undefined) => Promise<import("./models/os").OsUpdateVersions>;
            isArchitectureCompatibleWith: (osArchitecture: string, applicationArchitecture: string) => boolean;
            getSupervisorReleaseByDeviceType: (deviceTypeId: number, version: string) => Promise<import("./types/models").SupervisorRelease | null>;
        };
        config: {
            getAll: () => Promise<import("./models/config").Config>;
            getDeviceTypes: () => Promise<import("./types/device-type-json").DeviceType[]>;
            getDeviceTypeManifestBySlug: (slugOrName: string) => Promise<import("./types/device-type-json").DeviceType>;
            getDeviceOptions: (deviceType: string) => Promise<(import("./types/device-type-json").DeviceTypeOptions | import("./types/device-type-json").DeviceInitializationOptions)[]>;
            getConfigVarSchema: (deviceType?: string | undefined) => Promise<import("./models/config").ConfigVarDefinition>;
        };
        release: {
            get: (commitOrIdOrRawVersion: string | number | import("./models/release").ReleaseRawVersionApplicationPair, options?: import("../typings/pinejs-client-core").ODataOptions<import("./types/models").Release>) => Promise<import("./types/models").Release>;
            getAllByApplication: (slugOrUuidOrId: string | number, options?: import("../typings/pinejs-client-core").ODataOptions<import("./types/models").Release>) => Promise<import("./types/models").Release[]>;
            getLatestByApplication: (slugOrUuidOrId: string | number, options?: import("../typings/pinejs-client-core").ODataOptions<import("./types/models").Release>) => Promise<import("./types/models").Release | undefined>;
            getWithImageDetails: (commitOrIdOrRawVersion: string | number | import("./models/release").ReleaseRawVersionApplicationPair, options?: {
                release?: import("../typings/pinejs-client-core").ODataOptions<import("./types/models").Release> | undefined;
                image?: import("../typings/pinejs-client-core").ODataOptions<import("./types/models").Image> | undefined;
            }) => Promise<import("./models/release").ReleaseWithImageDetails>;
            createFromUrl: (slugOrUuidOrId: string | number, urlDeployOptions: import("./util/builder").BuilderUrlDeployOptions) => Promise<number>;
            finalize: (commitOrIdOrRawVersion: string | number | import("./models/release").ReleaseRawVersionApplicationPair) => Promise<void>;
            setIsInvalidated: (commitOrIdOrRawVersion: string | number | import("./models/release").ReleaseRawVersionApplicationPair, isInvalidated: boolean) => Promise<void>;
            setNote: (commitOrIdOrRawVersion: string | number | import("./models/release").ReleaseRawVersionApplicationPair, noteOrNull: string | null) => Promise<void>;
            setKnownIssueList: (commitOrIdOrRawVersion: string | number | import("./models/release").ReleaseRawVersionApplicationPair, knownIssueListOrNull: string | null) => Promise<void>;
            tags: {
                getAllByApplication(slugOrUuidOrId: string | number, options?: import("../typings/pinejs-client-core").ODataOptions<import("./types/models").ReleaseTag>): Promise<import("./types/models").ReleaseTag[]>;
                getAllByRelease(commitOrIdOrRawVersion: string | number | import("./models/release").ReleaseRawVersionApplicationPair, options?: import("../typings/pinejs-client-core").ODataOptions<import("./types/models").ReleaseTag>): Promise<import("./types/models").ReleaseTag[]>;
                set: (parentParam: string | number | import("../typings/utils").Dictionary<unknown>, key: string, value: string) => Promise<void>;
                remove: (parentParam: string | number | import("../typings/utils").Dictionary<unknown>, key: string) => Promise<void>;
            };
        };
        service: {
            getAllByApplication: (slugOrUuidOrId: string | number, options?: import("../typings/pinejs-client-core").ODataOptions<import("./types/models").Service>) => Promise<import("./types/models").Service[]>;
            var: {
                getAllByService: (parentParam: string | number | import("../typings/utils").Dictionary<unknown>, options?: import("../typings/pinejs-client-core").ODataOptions<import("./types/models").ServiceEnvironmentVariable> | undefined) => Promise<import("./types/models").ServiceEnvironmentVariable[]>;
                getAllByApplication(slugOrUuidOrId: string | number, options?: import("../typings/pinejs-client-core").ODataOptions<import("./types/models").ServiceEnvironmentVariable>): Promise<import("./types/models").ServiceEnvironmentVariable[]>;
                get: (parentParam: string | number | import("../typings/utils").Dictionary<unknown>, key: string) => Promise<string | undefined>;
                set: (parentParam: string | number | import("../typings/utils").Dictionary<unknown>, key: string, value: string) => Promise<void>;
                remove: (parentParam: string | number | import("../typings/utils").Dictionary<unknown>, key: string) => Promise<void>;
            };
        };
        image: {
            get(id: number, options?: import("../typings/pinejs-client-core").ODataOptions<import("./types/models").Image>): Promise<import("./types/models").Image>;
            getLogs: (id: number) => Promise<string>;
        };
        creditBundle: {
            getAllByOrg: (organization: string | number, options?: import("../typings/pinejs-client-core").ODataOptions<import("./types/models").CreditBundle> | undefined) => Promise<import("./types/models").CreditBundle[]>;
            create: (organization: string | number, featureId: number, creditsToPurchase: number) => Promise<import("../typings/pinejs-client-core").PostResult<import("./types/models").CreditBundle>>;
        };
        billing: {
            getAccount: (organization: string | number) => Promise<import("./models/billing").BillingAccountInfo>;
            getPlan: (organization: string | number) => Promise<import("./models/billing").BillingPlanInfo>;
            getBillingInfo: (organization: string | number) => Promise<import("./models/billing").BillingInfo>;
            updateBillingInfo: (organization: string | number, billingInfo: import("./models/billing").TokenBillingSubmitInfo) => Promise<import("./models/billing").BillingInfo>;
            /**
             * @namespace auth
             * @memberof balena
             */
            /**
             * @namespace logs
             * @memberof balena
             */
            /**
             * @namespace settings
             * @memberof balena
             */
            /**
             * @namespace utils
             * @memberof balena
             */
            removeBillingInfo: (organization: string | number) => Promise<import("./models/billing").BillingInfo>;
            updateAccountInfo: (organization: string | number, accountInfo: Partial<Pick<import("./models/billing").BillingAccountInfo, "email" | "cc_emails">>) => Promise<void>;
            changePlan: (organization: string | number, { cycle, ...restPlanChangeOptions }: import("./models/billing").PlanChangeOptions) => Promise<void>;
            getInvoices: (organization: string | number) => Promise<import("./models/billing").InvoiceInfo[]>;
            downloadInvoice(organization: string | number, invoiceNumber: string): Promise<Blob | import("balena-request").BalenaRequestStreamResult>;
        };
    };
    logs(): ({ request, sdkInstance, }: InjectedDependenciesParam, opts: InjectedOptionsParam) => {
        subscribe(uuidOrId: string | number, options?: import("./logs").LogsOptions | undefined): Promise<import("./logs").LogsSubscription>;
        history(uuidOrId: string | number, options?: import("./logs").LogsOptions | undefined): Promise<import("./logs").LogMessage[]>;
    };
    settings(): ({ settings }: InjectedDependenciesParam) => {
        get: (key: string) => Promise<string>;
        getAll: () => Promise<{
            [key: string]: string;
        }>;
    };
};
export type BalenaSDK = {
    [key in keyof typeof sdkTemplate]: ReturnType<ReturnType<(typeof sdkTemplate)[key]>>;
} & {
    interceptors: Interceptor[];
    request: BalenaRequest;
    pine: Pine;
    utils: import('./util').BalenaUtils;
    errors: typeof import('balena-errors');
    version: string;
};
/**
 * @namespace balena
 */
/**
 * @module balena-sdk
 */
/**
 * @summary Creates a new SDK instance using the default or the provided options.
 *
 * @description
 * The module exports a single factory function.
 *
 * @example
 * // with es6 imports
 * import { getSdk } from 'balena-sdk';
 * // or with node require
 * const { getSdk } = require('balena-sdk');
 *
 * const balena = getSdk({
 * 	apiUrl: "https://api.balena-cloud.com/",
 * 	dataDirectory: "/opt/local/balena"
 * });
 */
export declare const getSdk: ($opts?: SdkOptions) => BalenaSDK;
/**
 * @summary Set shared default options
 * @public
 * @function
 *
 * @description
 * Set options that are used by calls to `fromSharedOptions()`.
 * The options accepted are the same as those used in the main SDK factory function.
 * If you use this method, it should be called as soon as possible during app
 * startup and before any calls to `fromSharedOptions()` are made.
 *
 * @param {Object} options - The shared default options
 * @param {String} [options.apiUrl='https://api.balena-cloud.com/'] - the balena API url to use.
 * @param {String} [options.builderUrl='https://builder.balena-cloud.com/'] - the balena builder url to use.
 * @param {String} [options.deviceUrlsBase='balena-devices.com'] - the base balena device API url to use.
 * @param {Number} [options.requestLimit] - the number of requests per requestLimitInterval that the SDK should respect.
 * @param {Number} [options.requestLimitInterval = 60000] - the timespan that the requestLimit should apply to in milliseconds, defaults to 60000 (1 minute).
 * @param {Boolean} [options.retryRateLimitedRequests = false] - when enabled the sdk will retry requests that are failing with a 429 Too Many Requests status code and that include a numeric Retry-After response header.
 * @param {String|False} [options.dataDirectory='$HOME/.balena'] - *ignored in the browser unless false*, the directory where the user settings are stored, normally retrieved like `require('balena-settings-client').get('dataDirectory')`. Providing `false` creates an isolated in-memory instance.
 * @param {Boolean} [options.isBrowser] - the flag to tell if the module works in the browser. If not set will be computed based on the presence of the global `window` value.
 * @param {Boolean} [options.debug] - when set will print some extra debug information.
 *
 * @example
 * import { setSharedOptions } from 'balena-sdk';
 * setSharedOptions({
 * 	apiUrl: 'https://api.balena-cloud.com/',
 * 	builderUrl: 'https://builder.balena-cloud.com/',
 * 	isBrowser: true,
 * });
 */
export declare const setSharedOptions: (options: SdkOptions) => void;
/**
 * @summary Create an SDK instance using shared default options
 * @public
 * @function
 *
 * @description
 * Create an SDK instance using shared default options set using the `setSharedOptions()` method.
 * If options have not been set using this method, then this method will use the
 * same defaults as the main SDK factory function.
 *
 * @example
 * import { fromSharedOptions } from 'balena-sdk';
 * const sdk = fromSharedOptions();
 */
export declare const fromSharedOptions: () => BalenaSDK;
