import type { InjectedDependenciesParam } from '.';
declare const getSettings: ({ settings }: InjectedDependenciesParam) => {
    /**
     * @summary Get a single setting. **Only implemented in Node.js**
     * @name get
     * @function
     * @public
     * @memberof balena.settings
     *
     * @param {String} [key] - setting key
     * @fulfil {*} - setting value
     * @returns {Promise}
     *
     * @example
     * balena.settings.get('apiUrl').then(function(apiUrl) {
     * 	console.log(apiUrl);
     * });
     */
    get: (key: string) => Promise<string>;
    /**
     * @summary Get all settings **Only implemented in Node.js**
     * @name getAll
     * @function
     * @public
     * @memberof balena.settings
     *
     * @fulfil {Object} - settings
     * @returns {Promise}
     *
     * @example
     * balena.settings.getAll().then(function(settings) {
     * 	console.log(settings);
     * });
     */
    getAll: () => Promise<{
        [key: string]: string;
    }>;
};
export default getSettings;
